@@ -54,8 +54,9 @@ pushd "${release_directory}/.."
              --description "embARC - metadata embedded for archival content" \
              --icon "icons/embARC.icns"
 
+    mkdir build/distributions/macos/embARC.app/Contents/Helpers
     cp -a build/distributions/macos/embarc-cli.app/Contents/MacOS/embarc-cli \
-          build/distributions/macos/embARC.app/Contents/MacOS
+          build/distributions/macos/embARC.app/Contents/Helpers
     cp -a build/distributions/macos/embarc-cli.app/Contents/app/embarc-cli.cfg \
           build/distributions/macos/embARC.app/Contents/app
 popd
